errorhandler

package
v0.0.0-...-79d1445 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 17, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Handler

type Handler struct{}

Handler implements river.ErrorHandler to provide audible failure notification via espeak when a job exhausts all retries.

func (*Handler) HandleError

func (h *Handler) HandleError(ctx context.Context, job *rivertype.JobRow, err error) *river.ErrorHandlerResult

HandleError is called by River on each job error. It invokes espeak only when the job has exhausted all attempts (final failure).

func (*Handler) HandlePanic

func (h *Handler) HandlePanic(ctx context.Context, job *rivertype.JobRow, panicVal any, trace string) *river.ErrorHandlerResult

HandlePanic is called by River when a job panics. It invokes espeak only when the job has exhausted all attempts (final failure).

Jump to