Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Handler ¶
type Handler struct{}
Handler implements river.ErrorHandler to provide audible failure notification via espeak when a job exhausts all retries.
func (*Handler) HandleError ¶
func (h *Handler) HandleError(ctx context.Context, job *rivertype.JobRow, err error) *river.ErrorHandlerResult
HandleError is called by River on each job error. It invokes espeak only when the job has exhausted all attempts (final failure).
Click to show internal directories.
Click to hide internal directories.